@@ -884,6 +884,9 @@ static void reread_cd (gboolean ignore_no_media)
   GdkCursor *cursor;
   gboolean realized = GTK_WIDGET_REALIZED (main_window);
   
+  /* Make sure nothing is playing */
+  stop_playback ();
+  
   /* Set watch cursor */
   if (realized) {
     cursor = gdk_cursor_new_for_display (gdk_drawable_get_display (main_window->window), GDK_WATCH);
@@ -1544,7 +1547,7 @@ void on_duplicate_activate (GtkWidget *button, gpointer user_data)
   const gchar* device;
 
   device = nautilus_burn_drive_get_device (drive);
-  if (!g_spawn_command_line_sync (g_strconcat ("nautilus-cd-burner --source-device=", device, NULL), NULL, NULL, NULL, &error)) {
+  if (!g_spawn_command_line_async (g_strconcat ("nautilus-cd-burner --source-device=", device, NULL), &error)) {
       GtkWidget *dialog;
 
       dialog = gtk_message_dialog_new (GTK_WINDOW (main_window),
@@ -1844,6 +1847,7 @@ int main (int argc, char **argv)
 
   nautilus_burn_shutdown ();
 
+  g_option_context_free(ctx);
   g_object_unref (base_uri);
   g_object_unref (metadata);
   g_object_unref (extractor);
